package com.yijia.coupon.service.impl;

import java.util.List;
import com.yijia.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yijia.coupon.mapper.CouponInfoMapper;
import com.yijia.coupon.domain.CouponInfo;
import com.yijia.coupon.service.ICouponInfoService;

/**
 * 优惠劵Service业务层处理
 * 
 * @author yijia
 * @date 2021-04-27
 */
@Service
public class CouponInfoServiceImpl implements ICouponInfoService 
{
    @Autowired
    private CouponInfoMapper couponInfoMapper;

    /**
     * 查询优惠劵
     * 
     * @param id 优惠劵ID
     * @return 优惠劵
     */
    @Override
    public CouponInfo selectCouponInfoById(Integer id)
    {
        return couponInfoMapper.selectCouponInfoById(id);
    }

    /**
     * 查询优惠劵列表
     * 
     * @param couponInfo 优惠劵
     * @return 优惠劵
     */
    @Override
    public List<CouponInfo> selectCouponInfoList(CouponInfo couponInfo)
    {
        return couponInfoMapper.selectCouponInfoList(couponInfo);
    }

    /**
     * 新增优惠劵
     * 
     * @param couponInfo 优惠劵
     * @return 结果
     */
    @Override
    public int insertCouponInfo(CouponInfo couponInfo)
    {
        couponInfo.setCreateTime(DateUtils.getNowDate());
        return couponInfoMapper.insertCouponInfo(couponInfo);
    }

    /**
     * 修改优惠劵
     * 
     * @param couponInfo 优惠劵
     * @return 结果
     */
    @Override
    public int updateCouponInfo(CouponInfo couponInfo)
    {
        couponInfo.setUpdateTime(DateUtils.getNowDate());
        return couponInfoMapper.updateCouponInfo(couponInfo);
    }

    /**
     * 批量删除优惠劵
     * 
     * @param ids 需要删除的优惠劵ID
     * @return 结果
     */
    @Override
    public int deleteCouponInfoByIds(Integer[] ids)
    {
        return couponInfoMapper.deleteCouponInfoByIds(ids);
    }

    /**
     * 删除优惠劵信息
     * 
     * @param id 优惠劵ID
     * @return 结果
     */
    @Override
    public int deleteCouponInfoById(Integer id)
    {
        return couponInfoMapper.deleteCouponInfoById(id);
    }
}
