package com.yijia.customer.controller;

import java.util.List;

import com.yijia.common.core.domain.entity.SysDept;
import com.yijia.common.core.domain.model.LoginUser;
import com.yijia.common.utils.SecurityUtils;
import com.yijia.system.service.ISysDeptService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.yijia.common.annotation.Log;
import com.yijia.common.core.controller.BaseController;
import com.yijia.common.core.domain.AjaxResult;
import com.yijia.common.enums.BusinessType;
import com.yijia.customer.domain.CustomerCardRecordConsumption;
import com.yijia.customer.service.ICustomerCardRecordConsumptionService;
import com.yijia.common.utils.poi.ExcelUtil;
import com.yijia.common.core.page.TableDataInfo;

/**
 * 客户电子会员卡消费记录Controller
 *
 * @author yijia
 * @date 2021-04-13
 */
@RestController
@RequestMapping("/customer/consumption")
public class CustomerCardRecordConsumptionController extends BaseController
{
    @Autowired
    private ICustomerCardRecordConsumptionService customerCardRecordConsumptionService;
    @Autowired
    private ISysDeptService deptService;
    /**
     * 查询客户电子会员卡消费记录列表
     */
    @GetMapping("/list")
    public TableDataInfo list(CustomerCardRecordConsumption customerCardRecordConsumption)
    {
        if(customerCardRecordConsumption!=null &&customerCardRecordConsumption.getStationId()!=null){
            SysDept dept =new SysDept();
            dept.setDeptId(Long.valueOf(customerCardRecordConsumption.getStationId()));
            List<String> list = deptService.selectDeptId(dept);
            customerCardRecordConsumption.setStationIdList(list);
            customerCardRecordConsumption.setStationId(null);
        }
        startPage();
        List<CustomerCardRecordConsumption> list = customerCardRecordConsumptionService.selectCustomerCardRecordConsumptionList(customerCardRecordConsumption);
        return getDataTable(list);
    }

    /**
     * 导出客户电子会员卡消费记录列表
     */
    @Log(title = "客户电子会员卡消费记录", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(CustomerCardRecordConsumption customerCardRecordConsumption)
    {
        if(customerCardRecordConsumption!=null &&customerCardRecordConsumption.getStationId()!=null){
            SysDept dept =new SysDept();
            dept.setDeptId(Long.valueOf(customerCardRecordConsumption.getStationId()));
            List<String> list = deptService.selectDeptId(dept);
            customerCardRecordConsumption.setStationIdList(list);
            customerCardRecordConsumption.setStationId(null);
        }
        List<CustomerCardRecordConsumption> list = customerCardRecordConsumptionService.selectCustomerCardRecordConsumptionList(customerCardRecordConsumption);
        ExcelUtil<CustomerCardRecordConsumption> util = new ExcelUtil<CustomerCardRecordConsumption>(CustomerCardRecordConsumption.class);
        return util.exportExcel(list, "consumption");
    }

    /**
     * 获取客户电子会员卡消费记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('customer:consumption:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(customerCardRecordConsumptionService.selectCustomerCardRecordConsumptionById(id));
    }

    /**
     * 新增客户电子会员卡消费记录
     */
    @PreAuthorize("@ss.hasPermi('customer:consumption:add')")
    @Log(title = "客户电子会员卡消费记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CustomerCardRecordConsumption customerCardRecordConsumption)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        customerCardRecordConsumption.setStationId(currentUser.getUser().getDeptId());
        customerCardRecordConsumption.setStationName(currentUser.getUser().getDept().getDeptName());
        return toAjax(customerCardRecordConsumptionService.insertCustomerCardRecordConsumption(customerCardRecordConsumption));
    }

    /**
     * 修改客户电子会员卡消费记录
     */
    @PreAuthorize("@ss.hasPermi('customer:consumption:edit')")
    @Log(title = "客户电子会员卡消费记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CustomerCardRecordConsumption customerCardRecordConsumption)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        customerCardRecordConsumption.setStationId(currentUser.getUser().getDeptId());
        customerCardRecordConsumption.setStationName(currentUser.getUser().getDept().getDeptName());
        return toAjax(customerCardRecordConsumptionService.updateCustomerCardRecordConsumption(customerCardRecordConsumption));
    }

    /**
     * 删除客户电子会员卡消费记录
     */
    @PreAuthorize("@ss.hasPermi('customer:consumption:remove')")
    @Log(title = "客户电子会员卡消费记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(customerCardRecordConsumptionService.deleteCustomerCardRecordConsumptionByIds(ids));
    }

    /**
     * 获取客户电子会员卡消费汇总金额
     */
    @PreAuthorize("@ss.hasPermi('customer:consumption:xfAmtQuery')")
    @GetMapping(value = "xfAmtQuery")
    public AjaxResult xfAmtQuery(CustomerCardRecordConsumption customerCardRecordConsumption)
    {
        if(customerCardRecordConsumption!=null &&customerCardRecordConsumption.getStationId()!=null){
            SysDept dept =new SysDept();
            dept.setDeptId(Long.valueOf(customerCardRecordConsumption.getStationId()));
            List<String> list = deptService.selectDeptId(dept);
            customerCardRecordConsumption.setStationIdList(list);
            customerCardRecordConsumption.setStationId(null);
        }
        return AjaxResult.success(customerCardRecordConsumptionService.xfAmtQuery(customerCardRecordConsumption));
    }

    /**
     * 获取客户电子会员卡消费汇总折线图x 轴数据
     */
    @PreAuthorize("@ss.hasPermi('customer:consumption:listXdata')")
    @GetMapping(value = "listXdata")
    public TableDataInfo listXdata(CustomerCardRecordConsumption customerCardRecordConsumption)
    {
        if(customerCardRecordConsumption!=null &&customerCardRecordConsumption.getStationId()!=null){
            SysDept dept =new SysDept();
            dept.setDeptId(Long.valueOf(customerCardRecordConsumption.getStationId()));
            List<String> list = deptService.selectDeptId(dept);
            customerCardRecordConsumption.setStationIdList(list);
            customerCardRecordConsumption.setStationId(null);
        }
        List<CustomerCardRecordConsumption> list =customerCardRecordConsumptionService.listXdata(customerCardRecordConsumption);
        return getTable(list);
    }

    /**
     * 获取客户电子会员卡消费汇总折线图充值数据
     */
    @PreAuthorize("@ss.hasPermi('customer:consumption:listXFData')")
    @GetMapping(value = "/listXFData")
    public AjaxResult listXFData(CustomerCardRecordConsumption customerCardRecordConsumption)
    {
        if(customerCardRecordConsumption!=null &&customerCardRecordConsumption.getStationId()!=null){
            SysDept dept =new SysDept();
            dept.setDeptId(Long.valueOf(customerCardRecordConsumption.getStationId()));
            List<String> list = deptService.selectDeptId(dept);
            customerCardRecordConsumption.setStationIdList(list);
            customerCardRecordConsumption.setStationId(null);
        }
        customerCardRecordConsumption.setStatus("1");
        return AjaxResult.success(customerCardRecordConsumptionService.listXFData(customerCardRecordConsumption));
    }
    /**
     * 获取客户电子会员卡消费汇总折线图充值数据
     */
    @PreAuthorize("@ss.hasPermi('customer:consumption:listQydataXF')")
    @GetMapping(value = "/listQydataXF")
    public TableDataInfo listQydataXF(CustomerCardRecordConsumption customerCardRecordConsumption)
    {
        if(customerCardRecordConsumption!=null &&customerCardRecordConsumption.getStationId()!=null){
            SysDept dept =new SysDept();
            dept.setDeptId(Long.valueOf(customerCardRecordConsumption.getStationId()));
            List<String> list = deptService.selectDeptId(dept);
            customerCardRecordConsumption.setStationIdList(list);
            customerCardRecordConsumption.setStationId(null);
        }
        List<CustomerCardRecordConsumption> list =customerCardRecordConsumptionService.listQydataXF(customerCardRecordConsumption);
        return getTable(list);
    }
}
