package com.yijia.customer.controller;

import java.util.List;

import com.yijia.common.core.domain.entity.SysDept;
import com.yijia.common.core.domain.model.LoginUser;
import com.yijia.common.utils.SecurityUtils;
import com.yijia.system.service.ISysDeptService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.yijia.common.annotation.Log;
import com.yijia.common.core.controller.BaseController;
import com.yijia.common.core.domain.AjaxResult;
import com.yijia.common.enums.BusinessType;
import com.yijia.customer.domain.CustomerCardSetting;
import com.yijia.customer.service.ICustomerCardSettingService;
import com.yijia.common.utils.poi.ExcelUtil;
import com.yijia.common.core.page.TableDataInfo;

/**
 * 客户电子会员卡充值优惠设置Controller
 *
 * @author yijia
 * @date 2021-04-06
 */
@RestController
@RequestMapping("/customer/cardsetting")
public class CustomerCardSettingController extends BaseController
{
    @Autowired
    private ICustomerCardSettingService customerCardSettingService;

    @Autowired
    private ISysDeptService deptService;
    /**
     * 查询客户电子会员卡充值优惠设置列表
     */
    @GetMapping("/list")
    public TableDataInfo list(CustomerCardSetting customerCardSetting)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        SysDept dept =new SysDept();
        dept.setDeptId(currentUser.getUser().getDeptId());
        List<String> list = deptService.selectDeptId(dept);
        if(list!=null && list.size()>0){
            customerCardSetting.setStationIdList(list);
            customerCardSetting.setStationId(null);
        }
        startPage();
        List<CustomerCardSetting> settingList = customerCardSettingService.selectCustomerCardSettingList(customerCardSetting);
        return getDataTable(settingList);
    }

    /**
     * 导出客户电子会员卡充值优惠设置列表
     */
    @Log(title = "客户电子会员卡充值优惠设置", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(CustomerCardSetting customerCardSetting)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        SysDept dept =new SysDept();
        dept.setDeptId(currentUser.getUser().getDeptId());
        List<String> list = deptService.selectDeptId(dept);
        if(list!=null && list.size()>0){
            customerCardSetting.setStationIdList(list);
            customerCardSetting.setStationId(null);
        }
        List<CustomerCardSetting> settingList = customerCardSettingService.selectCustomerCardSettingList(customerCardSetting);
        ExcelUtil<CustomerCardSetting> util = new ExcelUtil<CustomerCardSetting>(CustomerCardSetting.class);
        return util.exportExcel(settingList, "setting");
    }

    /**
     * 获取客户电子会员卡充值优惠设置详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(customerCardSettingService.selectCustomerCardSettingById(id));
    }

    /**
     * 新增客户电子会员卡充值优惠设置
     */
    @Log(title = "客户电子会员卡充值优惠设置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CustomerCardSetting customerCardSetting)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        customerCardSetting.setStationId(currentUser.getUser().getDeptId());
        customerCardSetting.setStationName(currentUser.getUser().getDept().getDeptName());
        return toAjax(customerCardSettingService.insertCustomerCardSetting(customerCardSetting));
    }

    /**
     * 修改客户电子会员卡充值优惠设置
     */
    @Log(title = "客户电子会员卡充值优惠设置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CustomerCardSetting customerCardSetting)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        customerCardSetting.setStationId(currentUser.getUser().getDeptId());
        customerCardSetting.setStationName(currentUser.getUser().getDept().getDeptName());
        return toAjax(customerCardSettingService.updateCustomerCardSetting(customerCardSetting));
    }

    /**
     * 删除客户电子会员卡充值优惠设置
     */
    @Log(title = "客户电子会员卡充值优惠设置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(customerCardSettingService.deleteCustomerCardSettingByIds(ids));
    }
    @GetMapping(value = "/selectCustomerCardSetting")
    public AjaxResult selectCustomerCardSetting(CustomerCardSetting customerCardSetting)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        SysDept dept =new SysDept();
        dept.setDeptId(currentUser.getUser().getDeptId());
        List<String> list = deptService.selectDeptId(dept);
        if(list!=null && list.size()>0){
            customerCardSetting.setStationIdList(list);
            customerCardSetting.setStationId(null);
        }
        return AjaxResult.success(customerCardSettingService.selectCustomerCardSetting(customerCardSetting));
    }

}
