package com.yijia.customer.controller;
import com.yijia.common.core.domain.entity.SysDept;
import com.yijia.common.core.domain.model.LoginUser;
import com.yijia.common.utils.SecurityUtils;
import com.yijia.common.utils.poi.ExcelUtil;
import com.yijia.customer.domain.CustomerManage;
import com.yijia.customer.service.ICustomerManageService;
import com.yijia.system.service.ISysDeptService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.yijia.common.annotation.Log;
import com.yijia.common.core.controller.BaseController;
import com.yijia.common.core.domain.AjaxResult;
import com.yijia.common.enums.BusinessType;

import com.yijia.common.core.page.TableDataInfo;

import java.util.List;

/**
 * 客户管理Controller
 *
 * @author yijia
 * @date 2020-12-21
 */
@RestController
@RequestMapping("/customer/manage")
public class CustomerManageController extends BaseController
{
    @Autowired
    private ICustomerManageService customerManageService;
    @Autowired
    private ISysDeptService deptService;
    /**
     * 查询客户管理列表
     */
    @GetMapping("/list")
    public TableDataInfo list(CustomerManage customerManage)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        SysDept dept =new SysDept();
        dept.setDeptId(currentUser.getUser().getDeptId());
        List<String> list = deptService.selectDeptId(dept);
        if(list!=null && list.size()>0){
            customerManage.setStationIdList(list);
            customerManage.setStationId(null);
        }
        startPage();
        List<CustomerManage> customerManageList = customerManageService.selectCustomerManage(customerManage);
        return getDataTable(customerManageList);
    }

    /**
     * 导出客户管理列表
     */
    @Log(title = "客户管理", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(CustomerManage customerManage)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        SysDept dept =new SysDept();
        dept.setDeptId(currentUser.getUser().getDeptId());
        List<String> list = deptService.selectDeptId(dept);
        if(list!=null && list.size()>0){
            customerManage.setStationIdList(list);
            customerManage.setStationId(null);
        }
        List<CustomerManage> customerManageList = customerManageService.selectCustomerManageList(customerManage);
        ExcelUtil<CustomerManage> util = new ExcelUtil<CustomerManage>(CustomerManage.class);
        return util.exportExcel(customerManageList, "manage");
    }

    /**
     * 获取客户管理详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(customerManageService.selectCustomerManageById(id));
    }

    /**
     * 新增客户管理
     */
    @Log(title = "客户管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CustomerManage customerManage)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        customerManage.setStationId(currentUser.getUser().getDeptId());
        customerManage.setStationName(currentUser.getUser().getDept().getDeptName());
        return toAjax(customerManageService.insertCustomerManage(customerManage));
    }

    /**
     * 修改客户管理
     */
    @Log(title = "客户管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CustomerManage customerManage)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        customerManage.setStationId(currentUser.getUser().getDeptId());
        customerManage.setStationName(currentUser.getUser().getDept().getDeptName());
        return toAjax(customerManageService.updateCustomerManage(customerManage));
    }

    /**
     * 删除客户管理
     */
    @Log(title = "客户管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(customerManageService.deleteCustomerManageByIds(ids));
    }
}
