package com.yijia.customer.service.impl;

import java.util.List;
import com.yijia.common.utils.DateUtils;
import com.yijia.customer.domain.CustomerCardSettingDetail;
import com.yijia.customer.mapper.CustomerCardSettingDetailMapper;
import com.yijia.customer.service.ICustomerCardSettingDetailService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yijia.customer.mapper.CustomerCardSettingMapper;
import com.yijia.customer.domain.CustomerCardSetting;
import com.yijia.customer.service.ICustomerCardSettingService;

/**
 * 客户电子会员卡充值优惠设置Service业务层处理
 * 
 * @author yijia
 * @date 2021-04-06
 */
@Service
public class CustomerCardSettingServiceImpl implements ICustomerCardSettingService 
{
    @Autowired
    private CustomerCardSettingMapper customerCardSettingMapper;
    @Autowired
    private CustomerCardSettingDetailMapper customerCardSettingDetailMapper;

    /**
     * 查询客户电子会员卡充值优惠设置
     * 
     * @param id 客户电子会员卡充值优惠设置ID
     * @return 客户电子会员卡充值优惠设置
     */
    @Override
    public CustomerCardSetting selectCustomerCardSettingById(Long id)
    {
        return customerCardSettingMapper.selectCustomerCardSettingById(id);
    }

    /**
     * 查询客户电子会员卡充值优惠设置列表
     * 
     * @param customerCardSetting 客户电子会员卡充值优惠设置
     * @return 客户电子会员卡充值优惠设置
     */
    @Override
    public List<CustomerCardSetting> selectCustomerCardSettingList(CustomerCardSetting customerCardSetting)
    {

        return customerCardSettingMapper.selectCustomerCardSettingList(customerCardSetting);
    }

    @Override
    public CustomerCardSetting selectCustomerCardSetting(CustomerCardSetting customerCardSetting)
    {

        CustomerCardSetting setting =customerCardSettingMapper.selectCustomerCardSetting(customerCardSetting);
        if(setting!=null){
            CustomerCardSettingDetail detail = new CustomerCardSettingDetail();
            detail.setParentId(setting.getId());
            List<CustomerCardSettingDetail> detailList =customerCardSettingDetailMapper.selectCustomerCardSettingDetailList(detail);
            setting.setDetailList(detailList);
        }
        return setting;
    }

    /**
     * 新增客户电子会员卡充值优惠设置
     * 
     * @param customerCardSetting 客户电子会员卡充值优惠设置
     * @return 结果
     */
    @Override
    public int insertCustomerCardSetting(CustomerCardSetting customerCardSetting)
    {
        customerCardSetting.setCreateTime(DateUtils.getNowDate());
        int i =customerCardSettingMapper.insertCustomerCardSetting(customerCardSetting);
        if(customerCardSetting.getDetailList()!=null && customerCardSetting.getDetailList().size()>0){
            List<CustomerCardSettingDetail> list = customerCardSetting.getDetailList();
            for(CustomerCardSettingDetail detil:list){
                detil.setParentId(customerCardSetting.getId());
                customerCardSettingDetailMapper.insertCustomerCardSettingDetail(detil);
            }
        }
        return i;
    }

    /**
     * 修改客户电子会员卡充值优惠设置
     * 
     * @param customerCardSetting 客户电子会员卡充值优惠设置
     * @return 结果
     */
    @Override
    public int updateCustomerCardSetting(CustomerCardSetting customerCardSetting)
    {
        int i  =customerCardSettingMapper.updateCustomerCardSetting(customerCardSetting);
        CustomerCardSettingDetail detil = new CustomerCardSettingDetail();
        detil.setParentId(customerCardSetting.getId());
        customerCardSettingDetailMapper.deleteCustomerCardSettingDetail(detil);
        if(customerCardSetting.getDetailList()!=null && customerCardSetting.getDetailList().size()>0){
            List<CustomerCardSettingDetail> list = customerCardSetting.getDetailList();
            for(CustomerCardSettingDetail settingDetil:list){
                settingDetil.setParentId(customerCardSetting.getId());
                customerCardSettingDetailMapper.insertCustomerCardSettingDetail(settingDetil);
            }
        }
        return i;
    }

    /**
     * 批量删除客户电子会员卡充值优惠设置
     * 
     * @param ids 需要删除的客户电子会员卡充值优惠设置ID
     * @return 结果
     */
    @Override
    public int deleteCustomerCardSettingByIds(Long[] ids)
    {
        return customerCardSettingMapper.deleteCustomerCardSettingByIds(ids);
    }

    /**
     * 删除客户电子会员卡充值优惠设置信息
     * 
     * @param id 客户电子会员卡充值优惠设置ID
     * @return 结果
     */
    @Override
    public int deleteCustomerCardSettingById(Long id)
    {
        return customerCardSettingMapper.deleteCustomerCardSettingById(id);
    }

}
