package com.yijia.integral.controller;

import java.util.List;

import com.yijia.common.core.domain.entity.SysDept;
import com.yijia.common.core.domain.model.LoginUser;
import com.yijia.common.utils.SecurityUtils;
import com.yijia.system.service.ISysDeptService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.yijia.common.annotation.Log;
import com.yijia.common.core.controller.BaseController;
import com.yijia.common.core.domain.AjaxResult;
import com.yijia.common.enums.BusinessType;
import com.yijia.integral.domain.IntegralShopPic;
import com.yijia.integral.service.IIntegralShopPicService;
import com.yijia.common.utils.poi.ExcelUtil;
import com.yijia.common.core.page.TableDataInfo;

/**
 * 积分商城图片信息Controller
 *
 * @author yijia
 * @date 2021-03-18
 */
@RestController
@RequestMapping("/integral/pic")
public class IntegralShopPicController extends BaseController
{
    @Autowired
    private IIntegralShopPicService integralShopPicService;
    @Autowired
    private ISysDeptService sysDeptService;
    /**
     * 查询积分商城图片信息列表
     */
    @GetMapping("/list")
    public TableDataInfo list(IntegralShopPic integralShopPic)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        SysDept dept =new SysDept();
        dept.setDeptId(currentUser.getUser().getDeptId());
        List<String> list = sysDeptService.selectDeptId(dept);
        if(list!=null && list.size()>0){
            integralShopPic.setStationIdList(list);
            integralShopPic.setStationId(null);
        }
        startPage();
        List<IntegralShopPic> piclist = integralShopPicService.selectIntegralShopPicList(integralShopPic);
        return getDataTable(piclist);
    }

    /**
     * 导出积分商城图片信息列表
     */
    @PreAuthorize("@ss.hasPermi('integral:pic:export')")
    @Log(title = "积分商城图片信息", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(IntegralShopPic integralShopPic)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        SysDept dept =new SysDept();
        dept.setDeptId(currentUser.getUser().getDeptId());
        List<String> list = sysDeptService.selectDeptId(dept);
        if(list!=null && list.size()>0){
            integralShopPic.setStationIdList(list);
            integralShopPic.setStationId(null);
        }
        List<IntegralShopPic> piclist = integralShopPicService.selectIntegralShopPicList(integralShopPic);
        ExcelUtil<IntegralShopPic> util = new ExcelUtil<IntegralShopPic>(IntegralShopPic.class);
        return util.exportExcel(piclist, "pic");
    }

    /**
     * 获取积分商城图片信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('integral:pic:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(integralShopPicService.selectIntegralShopPicById(id));
    }

    /**
     * 新增积分商城图片信息
     */
    @PreAuthorize("@ss.hasPermi('integral:pic:add')")
    @Log(title = "积分商城图片信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody IntegralShopPic integralShopPic)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        integralShopPic.setStationId(currentUser.getUser().getDeptId());
        integralShopPic.setStationName(currentUser.getUser().getDept().getDeptName());
        return toAjax(integralShopPicService.insertIntegralShopPic(integralShopPic));
    }

    /**
     * 修改积分商城图片信息
     */
    @PreAuthorize("@ss.hasPermi('integral:pic:edit')")
    @Log(title = "积分商城图片信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody IntegralShopPic integralShopPic)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        integralShopPic.setStationId(currentUser.getUser().getDeptId());
        integralShopPic.setStationName(currentUser.getUser().getDept().getDeptName());
        return toAjax(integralShopPicService.updateIntegralShopPic(integralShopPic));
    }

    /**
     * 删除积分商城图片信息
     */
    @PreAuthorize("@ss.hasPermi('integral:pic:remove')")
    @Log(title = "积分商城图片信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(integralShopPicService.deleteIntegralShopPicByIds(ids));
    }
}
